@@ -48,6 +48,15 @@ int error(char* fmt, ...)
  return err;
 }
 
+int system_printf(char* fmt, ...)
+{
+ va_list ap;
+ char syscmd[MAX_SYSTEM_CMD];
+ va_start(ap,fmt);
+ vsprintf(syscmd,fmt,ap);
+ va_end(ap);
+ return system(syscmd);
+}
 
 void print_results(char*** res, int a, int b)
 {
