@@ -13,6 +13,8 @@
 #include <stdarg.h>
 #define ERR error("Error at line %d, file %s, compiled %s %s\n", __LINE__,__FILE__,__DATE__,__TIME__);
 #define ln() putchar('\n')
+#define MAX_SYSTEM_CMD 255
+int system_printf(char*, ...);
 int debug(char*, ...);
 int fatal(char*, ...);
 int error(char*, ...);
