@@ -8,14 +8,18 @@
  FILE: query.h */
 #ifndef __MORGOTHDBMA_QUERY_H__
 #define __MORGOTHDBMA_QUERY_H__
+#define MAX_ERROR_STRING 0XFF
+#define MAX_QUERY_LENGTH 2048
 #include <libpq-fe.h>
 #include <string.h>
 #include "consoleout.h"
 PGconn* connect_db(char*);
+PGconn* gtk_connect_db(char*,char*);
 void clear_result(PGresult**);
 void disconnect_db(PGconn**);
 PGresult* execute_silent_query(PGconn*,char*);
 PGresult* execute_query(PGconn*,char*);
-char*** pgres2pc(const PGresult*,int*,int*);
+void execute_printf_query(PGconn*,PGresult**,char*, char*,...);
+char*** pgres2pc3(const PGresult*,int*,int*);
 void free_p3c(char****,int,int);
 #endif
